Index: test/mjsunit/date-parse.js |
=================================================================== |
--- test/mjsunit/date-parse.js (revision 2740) |
+++ test/mjsunit/date-parse.js (working copy) |
@@ -250,8 +250,8 @@ |
// Test that we can parse our own date format. |
-// (Dates from 1970 to ~2070 with 95h steps.) |
-for (var i = 0; i < 24 * 365 * 100; i += 95) { |
+// (Dates from 1970 to ~2070 with 150h steps.) |
+for (var i = 0; i < 24 * 365 * 100; i += 150) { |
var ms = i * (3600 * 1000); |
var s = (new Date(ms)).toString(); |
assertEquals(ms, Date.parse(s), "parse own: " + s); |